Crate gapirs_drive_v3

Crate gapirs_drive_v3 

Re-exports

pub extern crate gapirs_common;

Re-exports

pub use crate::discovery::scopes::Scopes;
pub use ::gapirs_common as common;

Modules

api
deps
discovery

Enums

ApiCallError
GetTokenError

Traits

Error
Error is a trait representing the basic expectations for error values, i.e., values of type E in Result<T, E>.
Future
A future represents an asynchronous computation, commonly obtained by use of async.