Re-exports
pub extern crate gapirs_common;
Re-exports
pub use crate::discovery::scopes::Scopes;pub use ::gapirs_common as common;
Modules
Enums
Traits
- Error
Erroris a trait representing the basic expectations for error values, i.e., values of typeEinResult<T, E>.- Future
- A future represents an asynchronous computation, commonly obtained by use of
async.